@@ -1,6 +1,7 @@
 import logging
 import os
 import tempfile
+from urllib.parse import unquote_plus
 
 import boto3
 import botocore
@@ -100,6 +101,8 @@ def s3_download(bucket, key):
     """downloads a file from s3"""
     logger.debug(f's3_download("{bucket}", "{key}") called')
 
+    key = unquote_plus(key)
+
     s = boto3.session.Session()
     c = s.resource("s3")
     logger.info("boto3 s3 client created")
